==> react-native-wlc-1.0.23.tgz: package/src/component/molecules/FieldDropdown.tsx <==
// DropdownInput.tsx

import * as React from 'react';
import {HelperText, Text} from 'react-native-paper';
import RNPickerSelect, {PickerSelectProps} from 'react-native-picker-select';
import {useField} from 'formik';

export type FieldDropdownInputProps = Omit<
  PickerSelectProps,
  'onFocus' | 'label'
> & {
  name: string;
  placeholder?: string;
  title?: string;
};

export const FieldDropdownInput: React.FC<FieldDropdownInputProps> = ({
  onValueChange,
  name,
  title,
  ...props
}) => {
  const [, meta] = useField(name as any);

  const error = meta.touched && meta.error;

  return (
    <React.Fragment>
      {title && <Text variant="labelSmall">{title}</Text>}
      <RNPickerSelect
        onValueChange={onValueChange}
        style={pickerSelectStyles}
        {...props}
      />
      <HelperText type="error" visible={!!error}>
        {error}
      </HelperText>
    </React.Fragment>
  );
};

const pickerSelectStyles = {
  inputIOS: {
    fontSize: 16,
    paddingVertical: 16,
    paddingHorizontal: 10,
    borderWidth: 1,
    borderColor: 'gray',
    borderRadius: 4,
    color: 'black',
    paddingRight: 30, // to ensure the text is never behind the icon
    backgroundColor: 'white',
  },
  inputAndroid: {
    fontSize: 16,
    paddingVertical: 12,
    paddingHorizontal: 10,
    borderWidth: 0.5,
    borderColor: 'gray',
    borderRadius: 8,
    color: 'black',
    paddingRight: 30, // to ensure the text is never behind the icon
    backgroundColor: 'white',
  },
};

==> react-native-wlc-1.0.24.tgz: package/src/component/molecules/FieldDropdown.tsx <==
// DropdownInput

import * as React from "react";
import { HelperText, Text } from "react-native-paper";
import RNPickerSelect, { PickerSelectProps } from "react-native-picker-select";
import { useField } from "formik";

export type FieldDropdownInputProps = Omit<
  PickerSelectProps,
  "onFocus" | "label"
> & {
  name: string;
  placeholder?: string;
  title?: string;
};

export const FieldDropdownInput: React.FC<FieldDropdownInputProps> = ({
  onValueChange,
  name,
  title,
  ...props
}) => {
  const [, meta] = useField(name as any);

  const error = meta.touched && meta.error;

  return (
    <React.Fragment>
      {title && <Text variant="labelSmall">{title}</Text>}
      <RNPickerSelect
        onValueChange={onValueChange}
        style={pickerSelectStyles}
        {...props}
      />
      <HelperText type="error" visible={!!error}>
        {error}
      </HelperText>
    </React.Fragment>
  );
};

const pickerSelectStyles = {
  inputIOS: {
    fontSize: 16,
    paddingVertical: 16,
    paddingHorizontal: 10,
    borderWidth: 1,
    borderColor: "gray",
    borderRadius: 4,
    color: "black",
    paddingRight: 30, // to ensure the text is never behind the icon
    backgroundColor: "white",
  },
  inputAndroid: {
    fontSize: 16,
    paddingVertical: 12,
    paddingHorizontal: 10,
    borderWidth: 0.5,
    borderColor: "gray",
    borderRadius: 8,
    color: "black",
    paddingRight: 30, // to ensure the text is never behind the icon
    backgroundColor: "white",
  },
};
